VoprfClient

Struct VoprfClient 

pub struct VoprfClient<CS: CipherSuite> { /* private fields */ }
A client which engages with a VoprfServer in verifiable mode, meaning that the OPRF outputs can be checked against a server public key.

Implementations

Source

impl<CS: CipherSuite> VoprfClient<CS>

pub fn serialize(&self) -> Array<u8, VoprfClientLen<CS>>

Serialization into bytes

pub fn deserialize(input: &[u8]) -> Result<Self>

Deserialization from bytes

Errors

Error::Deserialization if failed to deserialize input.

Source

impl<CS: CipherSuite> VoprfClient<CS>

pub fn blind<R: TryRng + TryCryptoRng>( input: &[u8], blinding_factor_rng: &mut R, ) -> Result<VoprfClientBlindResult<CS>>

Computes the first step for the multiplicative blinding version of DH-OPRF.

Errors

Error::Input if the input is empty or longer then u16::MAX.

pub fn deterministic_blind_unchecked( input: &[u8], blind: <CS::Group as Group>::Scalar, ) -> Result<VoprfClientBlindResult<CS>>

Available on crate features danger only.

Computes the first step for the multiplicative blinding version of DH-OPRF, taking a blinding factor scalar as input instead of sampling from an RNG.

Caution

This should be used with caution, since it does not perform any checks on the validity of the blinding factor!

Errors

Error::Input if the input is empty or longer then u16::MAX.

pub fn finalize( &self, input: &[u8], evaluation_element: &EvaluationElement<CS>, proof: &Proof<CS>, pk: <CS::Group as Group>::Elem, ) -> Result<Output<CS::Hash>>

Computes the third step for the multiplicative blinding version of DH-OPRF, in which the client unblinds the server’s message.

Errors
pub fn batch_finalize<'a, I, II, IC, IM>( inputs: &'a II, clients: &'a IC, messages: &'a IM, proof: &Proof<CS>, pk: <CS::Group as Group>::Elem, ) -> Result<VoprfClientBatchFinalizeResult<'a, CS, I, II, IC, IM>>

Allows for batching of the finalization of multiple VoprfClient and EvaluationElement pairs

Errors

The resulting messages can each fail individually with Error::Input if the input is empty or longer then u16::MAX.